@@ -218,8 +218,11 @@ class Postgresql(object):
             raise RuntimeError("failed to open file:tmp/postgresql.log: %r" % exc)
 
 
-def skipIfNotFound(arg=None):
-    from unittest import skipIf
+def skipIfNotInstalled(arg=None):
+    if sys.version_info < (2, 7):
+        from unittest2 import skipIf
+    else:
+        from unittest import skipIf
 
     def decorator(fn, path=arg):
         if path:
@@ -239,6 +242,9 @@ def skipIfNotFound(arg=None):
         return decorator
 
 
+skipIfNotFound = skipIfNotInstalled
+
+
 def find_program(name, subdirs):
     path = get_path_of(name)
     if path:
